@@ -1,6 +1,6 @@
 /*
  *   stunnel       TLS offloading and load-balancing proxy
- *   Copyright (C) 1998-2023 Michal Trojnara <Michal.Trojnara@stunnel.org>
+ *   Copyright (C) 1998-2024 Michal Trojnara <Michal.Trojnara@stunnel.org>
  *
  *   This program is free software; you can redistribute it and/or modify it
  *   under the terms of the GNU General Public License as published by the
@@ -1160,19 +1160,19 @@ NOEXPORT int pin_cb(UI *ui, UI_STRING *uis) {
     return 1;
 }
 
-int (*ui_get_opener()) (UI *) {
+int (*ui_get_opener(void)) (UI *) {
     return NULL;
 }
 
-int (*ui_get_writer()) (UI *, UI_STRING *) {
+int (*ui_get_writer(void)) (UI *, UI_STRING *) {
     return NULL;
 }
 
-int (*ui_get_reader()) (UI *, UI_STRING *) {
+int (*ui_get_reader(void)) (UI *, UI_STRING *) {
     return hwnd ? pin_cb : NULL; /* only allow for UI in GUI mode */
 }
 
-int (*ui_get_closer()) (UI *) {
+int (*ui_get_closer(void)) (UI *) {
     return NULL;
 }
 
